@@ -131,6 +131,8 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QEnmlReader* reade
 	QObject::connect(actZoomout, SIGNAL(triggered()), this, SLOT(zoomoutView()));
 
 	ui.wvNoteEdit->page()->mainFrame()->addToJavaScriptWindowObject("JSApi",this);
+	ui.wvNoteEdit->setInputMethodHints(Qt::ImhPreferLowercase|Qt::ImhNoAutoUppercase);
+	ui.leNoteTitle->setInputMethodHints(Qt::ImhPreferLowercase|Qt::ImhNoAutoUppercase);
 }
 
 QNoteEditWindow::~QNoteEditWindow()
@@ -174,9 +176,10 @@ void QNoteEditWindow::saveNote()
 		m_Note.title = QString(ui.leNoteTitle->text().toUtf8()).toStdString();
 	}
 
-
-
-	m_pBackgroundJob->start();
+	if(m_Note.title.empty())
+		displayError("Unable to save note", "Title cannot be empty");
+	else
+		m_pBackgroundJob->start();
 }
 
 bool QNoteEditWindow::createNote()
