@@ -39,10 +39,13 @@ void QNoteSearchDialog::openTagSelectionDialog()
 	pDlg.exec();
 
 	foreach(QStringList tagData, selectedTagsList) { tagList += tagData[0] + " "; }
-	ui.pbSearchTags->setText(tagList);
+	if(tagList.size() > 0)
+		ui.pbSearchTags->setText(tagList);
+	else
+		ui.pbSearchTags->setText("Tags");
 }
 
-void QNoteSearchDialog::setTag(bool state, Tag tag)
+void QNoteSearchDialog::setTag(bool , Tag tag)
 {
 	selectedTagsList.append(QStringList() << QString::fromStdString(tag.name) << QString::fromStdString(tag.guid));
 }
